var _gpsStatus = false; // gps定位是否成功
var _cellStatus = false; // cell定位是否成功

var _gpsObj = null; // gps定位对象
var _baiduObj = null; // baidu对象
var _cellObj = null; // cell定位对象
var _callBackFunName = "";
var _needCityInfo = false;
var _MSG_POS_GPS = "POS_GPS";
var _MSG_POS_CELL = "POS_CELL";
var _MSG_GPS_CITY = "GPS_AND_CITY";
var _MSG_CELL_CITY = "CELL_AND_CITY";
var _MSG_ERROR_CITY = "ERROR_CITY";
var _MSG_FAIL_GPS = "FAIL_GPS";
var _MSG_FAIL_CELL = "FAIL_CELL";

var _needGps = true; // 是否需要使用GPS定位，默认是关闭的
var _needCell = true; // 是否需要使用cell id定位，默认是开启的

/**
 * 设置是否启用GPS定位
 * 
 * @param enable
 */
function setEnableGps(enable) {
	_needGps = enable;
}
/**
 * 设置是否启用cellid定位
 * 
 * @param enable
 */
function setEnableCell(enable) {
	_needCell = enable;
}
function startPos(callBackFunName, needCityInfo) {
	_callBackFunName = callBackFunName;
	_needCityInfo = needCityInfo;
	Log.i("postion", "version:" + Util.getVersion());
	// 如果是PC模拟器，直接上报模拟数据
	if (true == _needGps) {
		startGpsLocation();
	}
	if (true == _needCell) {
		var str= DeviceUtil.getOs();/*基座操作系统*/
		if(str!="ios"){
			startBaidu();
		}
	}
}

/** ==================================gps定位================================== */
/**
 * 开始GPS定位，超时时间2分种
 */
function startGpsLocation() {
	Log.i("postion", "startGpsLocation");
	if (_gpsObj == null) {
		_gpsObj = new Gps();
		Log.i("postion", "create Gps");
	}
	Log.i("postion", "Gps timeout:" + timeout);
	var timeout = 1000 * 60 * 2;
	_gpsObj.setTimeout(timeout);
	_gpsObj.onCallback = gpsCallback;
	_gpsObj.startPosition();
}

/**
 * GPS定位返回，如果是混合定位，谁先取取位置算谁的
 */
function gpsCallback() {
	Log.i("postion", "gpsCallback");

	if (_needCell && _cellStatus) {// 可以百度定位
		// 如果_cellStatus为真，则表时百度已经定成功，则放弃GPS定位
		return;
	}
	if (isReallySuccess(_gpsObj)) {
		var strPos = _gpsObj.latitude + ',' + _gpsObj.longitude;
		Log.i("postion", "gps success:" + strPos);
		stopPostion();
		notifyOK("gps", strPos, "");
	} else {
			if (_gpsObj) {
				_gpsObj.stopPosition();
				_gpsObj = null;
			}
			var fn = _callBackFunName + "('" + _MSG_FAIL_GPS + "', ' ' )";
			try {
				window.callFunction(fn);
			} catch (e) {
			}
	}

}
/**
 * 判断定位对象是否获取的有效的经纬度
 */
function isReallySuccess(posObj) {
	if (posObj != null && posObj.isSuccess()) {
		return (posObj.latitude > 10 && posObj.longitude > 10)
	}
	return false;
}
/** ==================================baidu定位================================== */
function startBaidu() {
	if (_gpsStatus) {
		// 如果gps已经定位成功，则返回
		return;
	}
	try {
		_baiduObj = new BaiduLocation();
		Log.i("postion", "startBaidu");
	} catch (e) {
		Log.i("postion", "baiduLocation not support");
		return;
	}
	_baiduObj.onCallback = baiduCallback;
	var timeOut = 5 * 1000;
	_baiduObj.setTimeout(timeOut);
	_baiduObj.startPosition();
}
/**
 * 百度定位回调
 */
function baiduCallback() {
	Log.i("postion", "baiduCallback");
	if (_gpsStatus) {
		// 如果gps已经定位成功，则返回
		return;
	}
	// 如果GPS已经定位成功 则放弃百度定位
	if (_baiduObj.isSuccess()) {
		var strPos = _baiduObj.latitude + ',' + _baiduObj.longitude;
		var address = _baiduObj.address;// 地址
		var locationtime = _baiduObj.locationtime;// 定位成功的时间
		var statuscode = _baiduObj.statuscode;// 返回定位状态
		var accuracy = _baiduObj.accuracy;// 获取定位精度。字符串类型，单位m。若获取失败则返回0
		Log.i("postion", "baidu success:" + strPos);
		stopPostion();
		notifyOK("cell", strPos, "");
	} else {
		Log.i("postion", "baidu unSuccess,statuscode:" + _baiduObj.statuscode);
		if (_baiduObj) {
			_baiduObj.stopPosition();
			_baiduObj = null;
		}
		var fn = _callBackFunName + "('" + _MSG_FAIL_CELL + "', ' ' )";
		try {
			window.callFunction(fn);
		} catch (e) {
		}
	}

}
/**
 * 全局方法，安全关闭定位的句柄
 */
function stopPostion() {
	Log.i("postion", "stopPostion");
	if (_baiduObj) {
		_baiduObj.stopPosition();
		_baiduObj = null;
	}
	if (_gpsObj) {
		_gpsObj.stopPosition();
		_gpsObj = null;
	}
}

/*--------------------------公共函数:发送通知等---------------------------------*/

/* 发送定位成功的通知 */
function notifyOK(type, strPos, strCity) {
	var fn = "";
	if (type == "gps") {
		_gpsStatus = true;
		fn = _callBackFunName + "('" + _MSG_POS_GPS + "',{pos:'" + strPos
				+ "'})";
	} else {
		_cellStatus = true;
		fn = _callBackFunName + "('" + _MSG_POS_CELL + "',{pos:'" + strPos
				+ "'})";
	}
	// 回调函数
	try {
		window.callFunction(fn);
	} catch (e) {
		// alert(e,"回调函数错误");
	}
	// 转换为地理位置
	if (_needCityInfo) {
		posToCity(strPos);
	}
}

/*--------------------------根据经纬度获取地理位置信息---------------------------------*/
var _strPos = "";
var _xmlHttp = null;
function posToCity(strPos) {
	Log.i("postion", "posToCity pos:" + strPos);
	_strPos = strPos;
	if (!_xmlHttp) {
		_xmlHttp = new XMLHttpRequest();
	}
	_xmlHttp.onreadystatechange = onPosToCity;
	var url = "http://ICUBE_URL/locateMap/posToCity.action?pos=" + strPos;
	Log.i("position", url);
	_xmlHttp.open("GET", url, true);
	_xmlHttp.send();
	window.setTimeout("posToCityTimeOut()", 1000 * 60);
}

var isPosToCityTimeOut = false;
function posToCityTimeOut() {
	if (_xmlHttp == null)
		return;
	isPosToCityTimeOut = true;
	var fn = _callBackFunName + "('" + _MSG_ERROR_CITY + "',{pos:'" + _strPos
			+ "'})";
	// 回调函数
	try {
		window.callFunction(fn);
	} catch (e) {
		// alert(e,"回调函数错误");
	}
}

function onPosToCity() {
	if (isPosToCityTimeOut)
		return;
	var fn = "";
	if (_xmlHttp.readyState == 4) {
		var strRsp = _xmlHttp.responseText;
		if (strRsp.indexOf("会话超时") >= 0) {
			alert("会话超时请重新登录！", reLogin);
		} else if (strRsp == "error") {
			fn = _callBackFunName + "('" + _MSG_ERROR_CITY + "',{pos:'"
					+ _strPos + "'})";
		} else {
			var msg = _MSG_CELL_CITY;
			if (_gpsStatus)
				msg = _MSG_GPS_CITY;
			fn = _callBackFunName + "('" + msg + "'," + strRsp + ")";
		}
	} else {
		fn = _callBackFunName + "('" + _MSG_ERROR_CITY + "',{pos:'" + _strPos
				+ "'})";
	}
	_xmlHttp = null;
	// 回调函数
	try {
		window.callFunction(fn);
	} catch (e) {
		// alert(e,"回调函数错误");
	}
}
